==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/INVESTMENTPLANNINGEQUIPMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INVESTMENTPLANNINGEQUIPMENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INVESTMENTPLANNINGEQUIPMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVESTMENTPLANNINGID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INVESTMENTPLANNINGEQUIPMENTID_Type", propOrder = {
    "investmentplanningid",
    "equipmentid"
})
public class INVESTMENTPLANNINGEQUIPMENTID_Type {

    @XmlElement(name = "INVESTMENTPLANNINGID", required = true)
    protected STANDARDENTITYID_Type investmentplanningid;
    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;

    /**
     * Gets the value of the investmentplanningid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getINVESTMENTPLANNINGID() {
        return investmentplanningid;
    }

    /**
     * Sets the value of the investmentplanningid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setINVESTMENTPLANNINGID(STANDARDENTITYID_Type value) {
        this.investmentplanningid = value;
    }

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/INVESTMENTPLANNINGEQUIPMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INVESTMENTPLANNINGEQUIPMENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="INVESTMENTPLANNINGEQUIPMENTID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}INVESTMENTPLANNINGID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INVESTMENTPLANNINGEQUIPMENTID_Type", propOrder = {
    "investmentplanningid",
    "equipmentid"
})
public class INVESTMENTPLANNINGEQUIPMENTID_Type {

    @XmlElement(name = "INVESTMENTPLANNINGID", required = true)
    protected STANDARDENTITYID_Type investmentplanningid;
    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;

    /**
     * Gets the value of the investmentplanningid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getINVESTMENTPLANNINGID() {
        return investmentplanningid;
    }

    /**
     * Sets the value of the investmentplanningid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setINVESTMENTPLANNINGID(STANDARDENTITYID_Type value) {
        this.investmentplanningid = value;
    }

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

}
